<?php

class ActivitiesController extends BuzzPhotosAppController {

	public function beforeFilter() {
		parent::beforeFilter();
		$this->Auth->allow(array(
			'index',
			'view',
			'ajax_get_times',
			'album',
			'share'
		));
	}

	protected function _adminPopulateLookups() {
		parent::_adminPopulateLookups();
		$this->set('themes', array(1, 2, 3, 4));
	}

	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();
		$fields['Activity.theme_id']['empty'] = false;

		return $fields;
	}

	public function index() {
		$activities = $this->{$this->modelClass}->find('all', array(
			'conditions' => array(
				'is_active' => 1
			),
			'contain' => array(
				'Image'
			)
		));
		$this->set('activities', $activities);
	}

	public function view($id) {
		$activity = $this->{$this->modelClass}->findById($id);

		if (empty($activity)) {
			throw new NotFoundException;
		}

		$this->set('data', $activity);
	}

	public function album($id) {
		$this->loadModel('BuzzPhotos.PhotoApi');
		$album = $this->PhotoApi->getAlbum($id);

		if (empty($album['Images'])) {
			return new NotFoundException;
		}

		$activities = array();

		foreach ($album['Images'] as $image) {
			$activities[]['Image'] = array(
				'filename' => 'image.jpg',
				'filepath' => 'http://' . $image['MediumKey'],
				'id' => $image['Id'],
				'type' => ''
			);

		}

		$this->set(compact('activities'));
	}

	public function ajax_get_times($id, $date) {
		$activity = $this->{$this->modelClass}->find('first', array(
			'conditions' => array(
				'id' => $id,
				'is_active' => 1
			),
			'contain' => array(
				'Image'
			)
		));

		if (empty($activity)) {
			throw new NotFoundException;
		}

		$this->loadModel('BuzzPhotos.PhotoApi');
		$data = $this->PhotoApi->getTimes($activity['Activity']['api_key'], $date);

		$this->set(compact('data'));
		$this->layout = 'ajax';
	}

	public function share($uuid) {
		$this->loadModel('BuzzPhotos.PhotoApi');
		$image = $this->PhotoApi->getImage($uuid);

		if (empty($image)) {
			return new NotFoundException;
		}

		$album = $this->PhotoApi->getAlbum($image['AlbumId']);

		// Extract and format the date
		$date = $album['AlbumDate'];
		$date = ltrim($date, '/Date(');
		$date = substr($date, 0, strpos($date, "+"));
		$date = $date / 1000;
		$date = date('jS F Y');

		$this->set(compact('image', 'album', 'date'));
	}

}